# == Class: etckeeper
#
# Puppet module to install, deploy and configure etckeeper.
#
class etckeeper (
  $package                = true,
  $enable                 = true,
  $etckeeper_package_name = $etckeeper::params::etckeeper_package_name,
  $etckeeper_service_name = $etckeeper::params::etckeeper_service_name,
  $etckeeper_config       = $etckeeper::params::etckeeper_config,
  $etckeeper_cron         = $etckeeper::params::etckeeper_cron
) inherits etckeeper::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  package { $etckeeper_package_name:
    ensure => $ensure_package,
  }

  if ($package == true) or ($package == latest) {
    exec { 'etckeeper init -d /etc':
      command => 'etckeeper init -d /etc',
      path    => '/usr/bin:/usr/sbin:/bin',
      onlyif  => 'test ! -d /etc/.git',
      require => Package[$etckeeper_package_name],
    }
  }

  file { $etckeeper_config:
    ensure  => $ensure_package,
    backup  => true,
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    source  => 'puppet:///modules/etckeeper/etc/etckeeper/etckeeper.conf',
    require => Package[$etckeeper_package_name],
  }

  file { $etckeeper_cron:
    ensure  => present,
    backup  => true,
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    source  => 'puppet:///modules/etckeeper/etc/cron.daily/etckeeper',
    require => Package[$etckeeper_package_name],
  }
}
# EOF
